#
# spec file for package thunderbolt-user-space
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           thunderbolt-user-space
Version:        0.9.3
Release:        5.4
Summary:        Thunderbolt Device Approval support
License:        BSD-3-Clause
Group:          System/Management
URL:            https://github.com/intel/thunderbolt-software-user-space
Source:         https://github.com/01org/thunderbolt-software-user-space/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         0001-flags-add-boost_system-library.patch
# Add support for Thunderbolt devices using Secure Connection in initramfs
Patch1:         0002-initramfs-support.patch
BuildRequires:  cmake >= 2.4.6
BuildRequires:  gcc-c++ >= 4.7
BuildRequires:  libdbus-c++-devel
BuildRequires:  libnl3-devel
BuildRequires:  pkgconfig
BuildRequires:  txt2tags
BuildRequires:  pkgconfig(dracut)
BuildRequires:  pkgconfig(udev)
Requires:       procps
%if 0%{?suse_version} > 1315
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel >= 1.33.1
%endif

%description
Thunderbolt is a hardware interface developed by Intel/Apple that
allows the connection of external peripherals to a computer.

These user-space components implement device approval support:

* Interaction with the kernel module for approving connected devices.
* ACL for auto-approving devices white-listed by the user.

%prep
%autosetup -p1 -n thunderbolt-software-user-space-%{version}

%build
%cmake \
  -DBUILD_TESTING:BOOL=OFF \
  -DEVENT_DISABLE_TESTS=ON
%cmake_build

%install
%cmake_install
rm -rf %{buildroot}%{_datadir}/doc/thunderbolt-user-space

%post
%udev_rules_update

%postun
%udev_rules_update

%files
%license COPYING
%doc README.md docs
%{_bindir}/tbtadm
%{_udevrulesdir}/60-tbtacl.rules
%{_udevrulesdir}/60-tbtxdomain.rules
%dir %{_prefix}/lib/dracut/modules.d/35thunderbolt/
%{_prefix}/lib/dracut/modules.d/35thunderbolt/module-setup.sh
%{_prefix}/lib/udev/tbtacl
%{_prefix}/lib/udev/tbtacl-write
%{_prefix}/lib/udev/tbtxdomain
%{_mandir}/man1/tbtadm.1%{?ext_man}
%{_datadir}/bash-completion/completions/tbtadm
%config %{_sysconfdir}/dracut.conf.d/35-thunderbolt.conf

%changelog
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Aug  4 2020 Frederik Möllers <frederik@die-sinlosen.de>
- Add support for Thunderbolt to initramfs (approved devices are authorized automatically)
  added: 0002-initramfs-support.patch
* Fri Dec 20 2019 Martin Pluskal <mpluskal@suse.com>
- Cleanup spec file
- Correct usage of url and source url
- Mark documentation and license as such
* Thu Mar 15 2018 ndas@suse.de
- fate reference: this package needed for thunderbolt support in
  SLE12SP4 (fate#325100)
* Fri Feb 23 2018 ndas@suse.de
- Updated to 0.9.3
  * xdomain: added loading Thunderbolt networking driver automatically on XDomain connection
  * tbtadm: added peers command and XDomain is now shown in the topology output
  * tbtadm: added add command for adding to ACL database without approve command
  * tbtadm: fixed adding to ACL database in security level 0
  * tbtadm: fixed Coverity error reformatting string array initialization
  * tbtadm: fixed multi-controller topology tree
  * tbtadm: improved readability of console output
  * tests: added automatic testing in umockdev simulated environment with docker
  * build: remove unneeded libboost-program-options dependency
* Tue Oct 17 2017 ndas@suse.de
- Do not pull boost-devel on Factory (bsc#1062800)
* Tue Oct 10 2017 ndas@suse.de
- Add missing rpm group
* Mon Oct  9 2017 ndas@suse.de
- Minor version release with new command (approve),
  new flag (--once), bash completion and more improvements and fixes.
* Mon Oct  2 2017 jengelh@inai.de
- Redo description to describe the package, not the protocol.
* Thu Sep 14 2017 ndas@suse.de
- Initial version 0.9.1 (fate#324014)
